VAccordionProperties class
Theme extension for the Visa Nova Design System.
Overriding Theme Tokens in Downstream Apps
To override theme tokens like errorBorderColor in your consuming app:
final customTheme = ThemeData(
extensions: [
VDefaultThemeProps(
errorBorderColor: Color(0xFFFF0000), // Your custom error border color
// ... other theme properties
),
],
);
// Then apply it to your MaterialApp:
MaterialApp(
theme: customTheme,
// ...
)
Accessing Theme Tokens in Widgets
final theme = Theme.of(context).extension<VDefaultThemeProps>();
final errorColor = theme?.errorBorderColor ?? VColors.negativeGraphics;
Constructors
Properties
- bodyTextStyle → TextStyle?
-
final
- borderRadius → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerBoldTextStyle → TextStyle?
-
final
- headerBorderRadius → double?
-
final
- headerSubtleTextStyle → TextStyle?
-
final
- headerTextStyle → TextStyle?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtleBorderRadius → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited