elevation property
double?
get
elevation
Elevation to be applied on the chip relative to its parent.
This controls the size of the shadow below the chip.
Defaults to 0. The value is always non-negative.
Implementation
double? get elevation;