VMatTab class
A material design VMatTabBar vTab.
If both icon and text are provided, the text is displayed below the icon.
See also:
- VMatTabBar, which displays a row of vTabs.
- VMatTabBarView, which displays a widget for the currently selected vTab.
- TabController, which coordinates vTab selection between a VMatTabBar and a VMatTabBarView.
- material.io/design/components/vTabs.html
- Inheritance
- Implemented types
Constructors
- VMatTab({Key? key, String? text, Widget? icon, EdgeInsetsGeometry iconMargin = const EdgeInsets.only(bottom: 8.0), double? height, Widget? child})
-
Creates a material design VMatTabBar vTab.
const
Properties
- child → Widget?
-
The widget to be used as the vTab's label.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
The height of the VMatTab.
final
- icon → Widget?
-
An icon to display as the vTab's label.
final
- iconMargin → EdgeInsetsGeometry
-
The margin added around the vTab's icon.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- preferredSize → Size
-
The size this widget would prefer if it were otherwise unconstrained.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String?
-
The text to display as the vTab's label.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited