VButtonStyle class

Inheritance

Constructors

VButtonStyle({Color? backgroundColorDisabled, Color? backgroundColorActive, Color? foregroundColorDisabled, Color? foregroundColorActive, Color? overlayColorPressed, Color? overlayColorFocused, Color? shadowColor, double? elevation, double? borderRadiusActive, double? borderRadiusDisabled, Size? minimumSize, BorderSide? borderSideActive, BorderSide? borderSideDisabled, EdgeInsetsGeometry? padding})
const

Properties

backgroundColorActive → Color?
final
backgroundColorDisabled → Color?
final
borderRadiusActive → double?
final
borderRadiusDisabled → double?
final
borderSideActive → BorderSide?
final
borderSideDisabled → BorderSide?
final
elevation → double?
final
foregroundColorActive → Color?
final
foregroundColorDisabled → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
minimumSize → Size?
final
overlayColorFocused → Color?
final
overlayColorPressed → Color?
final
padding → EdgeInsetsGeometry?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowColor → Color?
final
type → Object
The extension's type.
no setterinherited

Methods

copyWith({Color? backgroundColorDisabled, Color? backgroundColorActive, Color? foregroundColorDisabled, Color? foregroundColorActive, Color? overlayColorPressed, Color? overlayColorFocused, Color? shadowColor, double? elevation, double? borderRadiusActive, double? borderRadiusDisabled, Size? minimumSize, TextStyle? buttonTextStyle, BorderSide? borderSideActive, BorderSide? borderSideDisabled, EdgeInsetsGeometry? padding}) → VButtonStyle
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<VButtonStyle>? other, double t) → VButtonStyle
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited