VFlagStyle class

Inheritance

Constructors

VFlagStyle({Color? infoIconColor, Color? warningIconColor, Color? errorIconColor, Color? successIconColor, Color? linkTextColor, Color? linkUnderlineColor, Color? closeIconColor, Color? titleTextColor, Color? descriptionTextColor, TextStyle? linkTextStyle, TextStyle? titleTextStyle, TextStyle? descriptionTextStyle, EdgeInsetsGeometry? closeIconPadding, VButtonStyle? linkStyle})
const

Properties

closeIconColor Color?
final
closeIconPadding EdgeInsetsGeometry?
final
descriptionTextColor Color?
final
descriptionTextStyle TextStyle?
final
errorIconColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
infoIconColor Color?
final
linkStyle VButtonStyle?
final
linkTextColor Color?
final
linkTextStyle TextStyle?
final
linkUnderlineColor Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
successIconColor Color?
final
titleTextColor Color?
final
titleTextStyle TextStyle?
final
type Object
The extension's type.
no setterinherited
warningIconColor Color?
final

Methods

copyWith({Color? infoIconColor, dynamic warningIconColor, dynamic errorIconColor, dynamic successIconColor, dynamic linkTextColor, dynamic linkUnderlineColor, dynamic closeIconColor, dynamic titleTextColor, dynamic descriptionTextColor, TextStyle? linkTextStyle, TextStyle? titleTextStyle, TextStyle? descriptionTextStyle, EdgeInsetsGeometry? closeIconPadding, VButtonStyle? linkStyle}) VFlagStyle
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<VFlagStyle>? other, double t) VFlagStyle
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited