VInput class

Inheritance

Constructors

VInput({Key? key, TextEditingController? myLocalController, String? leadingSvgIcon, String? trailingSvgIcon, int? maxNumOfLines, int? minNumOfLines, String? topLabelText, bool hasError = false, bool isEnabled = true, bool hideText = false, int? textLength, bool maxLengthEnforced = false, TextAlign alignText = TextAlign.left, TextInputType? keyboardType, TextInputAction? inputAction, bool expand = false, bool showScrollbar = false, dynamic saved(String?)?, dynamic editingComplete()?, dynamic onSubmitted(String?)?, dynamic changed(String?)?, dynamic tapped()?, dynamic onPressed()?, String? errorText = "This field can't be empty", Widget? inlineMessage, FocusNode? inputFocusNode, bool isTopLabelCenter = false, double? textSize, bool isPrefix = false, bool isSuffix = false, bool isLeading = false, bool isTrailing = false, String? trailingSemanticLabel, double? letterSpacing, double? cursorHeight, Widget? trailingIcon, bool? appearOnFocus = false, bool isReadOnly = false, bool? isFocused = false, bool hasInlineMessage = false, Widget? prefix, Widget? suffix, VInputStyle? style, VExt? vExt, bool? isLabelInLine = false, List<TextInputFormatter>? inputFormatters, void onDidGainAccessibilityFocus()?, bool isComboBox = false, TextCapitalization textCapitalization = TextCapitalization.none, bool autoCorrect = false, List<String>? autofillHints, bool enableSuggestions = true, String? inputSemanticReadout, String hintText = "", TextStyle? hintTextStyle, String? obscuringCharacter, String? initialValue, String? semanticsError = "Error", bool? flexHeight = false, void onTapOutside(PointerDownEvent)?, bool? enableInteractiveSelection})

Properties

alignText → TextAlign
final
appearOnFocus → bool?
final
autoCorrect → bool
final
autofillHints → List<String>?
final
changed → dynamic Function(String?)?
final
cursorHeight → double?
final
editingComplete → dynamic Function()?
final
enableInteractiveSelection → bool?
final
enableSuggestions → bool
final
errorText → String?
final
expand → bool
final
flexHeight → bool?
final
hasError → bool
final
hashCode → int
The hash code for this object.
no setterinherited
hasInlineMessage → bool
final
hideText → bool
final
hintText → String
final
hintTextStyle → TextStyle?
final
initialValue → String?
final
inlineMessage → Widget?
final
inputAction → TextInputAction?
final
inputFocusNode → FocusNode?
final
inputFormatters → List<TextInputFormatter>?
final
inputSemanticReadout → String?
final
isComboBox → bool
final
isEnabled → bool
final
isFocused ↔ bool?
getter/setter pair
isLabelInLine → bool?
final
isLeading → bool
final
isPrefix → bool
final
isReadOnly → bool
final
isSuffix → bool
final
isTopLabelCenter → bool
final
isTrailing → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → TextInputType?
final
leadingSvgIcon → String?
final
letterSpacing → double?
final
maxLengthEnforced → bool
final
maxNumOfLines → int?
final
minNumOfLines → int?
final
myLocalController → TextEditingController?
final
obscuringCharacter → String?
final
onDidGainAccessibilityFocus → void Function()?
final
onPressed → dynamic Function()?
final
onSubmitted → dynamic Function(String?)?
final
onTapOutside → void Function(PointerDownEvent)?
final
prefix → Widget?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saved → dynamic Function(String?)?
final
semanticsError → String?
final
showScrollbar → bool
final
style → VInputStyle?
final
suffix → Widget?
final
tapped → dynamic Function()?
final
textCapitalization → TextCapitalization
final
textLength → int?
final
textSize → double?
final
topLabelText → String?
final
trailingIcon → Widget?
final
trailingSemanticLabel → String?
final
trailingSvgIcon → String?
final
vExt → VExt?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<VInput>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited