VProgressStyle class

Inheritance

Constructors

VProgressStyle({Color? backgroundColor, Color? color, TextStyle? circularLabelTextStyle, double? linearRadius, double? circularSize, Color? successColor})
const

Properties

backgroundColor → Color?
final
circularLabelTextStyle → TextStyle?
final
circularSize → double?
final
color → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
linearRadius → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
successColor → Color?
final
type → Object
The extension's type.
no setterinherited

Methods

copyWith({Color? backgroundColor, Color? color, Color? successColor, TextStyle? circularLabelTextStyle, double? linearRadius, double? circularSize}) → VProgressStyle
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<VProgressStyle>? other, double t) → VProgressStyle
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited