VRadioStyle class

Inheritance

Constructors

VRadioStyle({Color? fillColor, Color? fillColorPressed, Color? fillColorDisabled, Color? titleTextColor, Color? titleTextColorDisabled, Color? subtitleTextColor, Color? subtitleTextColorDisabled, Color? overlayColor})
const

Properties

fillColor Color?
final
fillColorDisabled Color?
final
fillColorPressed Color?
final
hashCode int
The hash code for this object.
no setterinherited
overlayColor Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitleTextColor Color?
final
subtitleTextColorDisabled Color?
final
titleTextColor Color?
final
titleTextColorDisabled Color?
final
type Object
The extension's type.
no setterinherited

Methods

copyWith({Color? fillColor, dynamic fillColorPressed, dynamic fillColorDisabled, dynamic iconColor, dynamic iconColorError, dynamic titleTextColor, dynamic titleTextColorDisabled, dynamic titleTextColorError, dynamic subtitleTextColor, dynamic subtitleTextColorDisabled, dynamic subtitleTextColorError, dynamic overlayColor}) VRadioStyle
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<VRadioStyle>? other, double t) VRadioStyle
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited