VSectionMessage class

Inheritance

Constructors

VSectionMessage({Key? key, SectionMessageState sectionMessageState = SectionMessageState.informational, bool hasClose = false, VoidCallback? onClosePressed, bool visible = false, String semanticsCloseLabel = close, String closeIconButton = closeIcon, bool hasTitle = false, String title = "Title", required String description, bool hasAction = false, String action = "Action", VoidCallback? onActionPressed, bool hasLink = false, String link = "", VoidCallback? onLinkPressed, MainAxisAlignment? buttonMainAxisAlignment, Widget? subtleSectionMessageIcon, Widget? infoSectionMessageIcon, Widget? warningSectionMessageIcon, Widget? errorSectionMessageIcon, Widget? successSectionMessageIcon, VSectionMessageStyle? style})
const

Properties

action → String
final
buttonMainAxisAlignment → MainAxisAlignment?
final
closeIconButton → String
final
description → String
final
errorSectionMessageIcon → Widget?
final
hasAction → bool
final
hasClose → bool
final
hashCode → int
The hash code for this object.
no setterinherited
final
hasTitle → bool
final
infoSectionMessageIcon → Widget?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
final
onActionPressed → VoidCallback?
final
onClosePressed → VoidCallback?
final
onLinkPressed → VoidCallback?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sectionMessageState → SectionMessageState
final
semanticsCloseLabel → String
final
style → VSectionMessageStyle?
final
subtleSectionMessageIcon → Widget?
final
successSectionMessageIcon → Widget?
final
title → String
final
visible → bool
final
warningSectionMessageIcon → Widget?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getFirstLineStyle(bool hasTitle) → TextStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited