VSectionMessageStyle class

Inheritance

Constructors

VSectionMessageStyle({Color? normalColor, Color? infoBGColor, Color? infoIconColor, Color? infoHLColor, Color? warningBGColor, Color? warningIconColor, Color? warningHLColor, Color? errorBGColor, Color? errorIconColor, Color? errorHLColor, Color? successBGColor, Color? successIconColor, Color? successHLColor, Color? subtleBGColor, Color? subtleHLColor, Color? subtleIconColor, Color? borderColor})
const

Properties

borderColor → Color?
final
errorBGColor → Color?
final
errorHLColor → Color?
final
errorIconColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
infoBGColor → Color?
final
infoHLColor → Color?
final
infoIconColor → Color?
final
normalColor → Color?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtleBGColor → Color?
final
subtleHLColor → Color?
final
subtleIconColor → Color?
final
successBGColor → Color?
final
successHLColor → Color?
final
successIconColor → Color?
final
type → Object
The extension's type.
no setterinherited
warningBGColor → Color?
final
warningHLColor → Color?
final
warningIconColor → Color?
final

Methods

copyWith({Color? normalColor, dynamic infoBGColor, dynamic infoIconColor, dynamic infoHLColor, dynamic warningBGColor, dynamic warningIconColor, dynamic warningHLColor, dynamic errorBGColor, dynamic errorIconColor, dynamic errorHLColor, dynamic successBGColor, dynamic successIconColor, dynamic successHLColor, dynamic subtleBGColor, dynamic subtleHLColor, dynamic subtleIconColor, dynamic borderColor}) → VSectionMessageStyle
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<VSectionMessageStyle>? other, double t) → VSectionMessageStyle
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited