VSelect class

Inheritance

Constructors

VSelect({Key? key, required List<PopupMenuEntry> itemBuilder(BuildContext), Widget? buttonText, bool isDisabled = false, Icon? icons, void onSelected(dynamic)?, void onCanceled()?, bool validate = false, String validateText = "An error occurred", Widget? inLineMessage, String? headerLabel, bool isReadOnly = false, FocusNode? focusNode, bool isInline = false, VSelectStyle? style, VExt? vExt, MainAxisAlignment? mainAxisAlignment, bool showErrorMessage = false, bool showErrorIcon = false, String? semanticsLabel, void onDidGainAccessibilityFocus()?, PopupMenuPosition? position = PopupMenuPosition.under, Offset offset = const Offset(0, 10), String? semanticReadout})

Properties

buttonText ↔ Widget?
getter/setter pair
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
headerLabel → String?
final
icons → Icon?
final
inLineMessage → Widget?
final
isDisabled → bool
final
isInline → bool
final
isReadOnly → bool
final
itemBuilder → List<PopupMenuEntry> Function(BuildContext)
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mainAxisAlignment → MainAxisAlignment?
final
offset → Offset
final
onCanceled → void Function()?
final
onDidGainAccessibilityFocus → void Function()?
final
onSelected → void Function(dynamic)?
final
position → PopupMenuPosition?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticReadout → String?
final
semanticsLabel → String?
final
showErrorIcon → bool
final
showErrorMessage → bool
final
style → VSelectStyle?
final
validate → bool
final
validateText → String
final
vExt → VExt?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<VSelect>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited