VSelectStyle class

Inheritance

Constructors

VSelectStyle({Color? backgroundColor, Color? splashColor, Color? iconColor, Color? borderColor, Color? dropDownBorderColor, Color? bottomBarColor, Color? labelTextColor, Color? buttonTextColor, Color? validateTextColor, Color? errorIconColor, Color? dropdownColor, Color? borderErrorColor, TextStyle? headerTitleTextStyle, TextStyle? labelTextStyle, TextStyle? validateTextStyle, double? borderRadius, double? dropDownElevation, double? dropDownBorderRadius, double? buttonHeight, double? buttonWidth, double? dropdownWidth})
const

Properties

backgroundColor → Color?
final
borderColor → Color?
final
borderErrorColor → Color?
final
borderRadius → double?
final
bottomBarColor → Color?
final
buttonHeight → double?
final
buttonTextColor → Color?
final
buttonWidth → double?
final
final
final
final
final
final
errorIconColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
headerTitleTextStyle → TextStyle?
final
iconColor → Color?
final
labelTextColor → Color?
final
labelTextStyle → TextStyle?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
splashColor → Color?
final
type → Object
The extension's type.
no setterinherited
validateTextColor → Color?
final
validateTextStyle → TextStyle?
final

Methods

copyWith({Color? backgroundColor, dynamic splashColor, dynamic iconColor, dynamic dropDownBorderColor, dynamic bottomBarColor, dynamic borderColor, dynamic labelTextColor, dynamic buttonTextColor, dynamic validateTextColor, dynamic errorIconColor, dynamic dropdownColor, dynamic borderErrorColor, TextStyle? headerTitleTextStyle, dynamic labelTextStyle, dynamic validateTextStyle, double? borderRadius, dynamic dropDownElevation, dynamic dropDownBorderRadius, dynamic buttonHeight, dynamic buttonWidth, dynamic dropdownWidth}) → VSelectStyle
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<VSelectStyle>? other, double t) → VSelectStyle
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited