VToggle class

Inheritance

Constructors

VToggle({Key? key, required List<bool> isSelected, required List<Widget> toggleListItems, CrossAxisAlignment? topLabelAlignment, Widget? topLabel, List<bool>? disabledItems, Axis axis = Axis.horizontal, dynamic onPressed(int)?, bool isDisabled = false, bool isMultiSelect = false, TextStyle? toggleTextStyle, VToggleStyle? style, VExt? vExt})
const

Properties

axis → Axis
final
disabledItems → List<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
isDisabled → bool
final
isMultiSelect → bool
When true, multiple items can be selected. When false (default), only one item can be selected at a time.
final
isSelected → List<bool>
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPressed → dynamic Function(int)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → VToggleStyle?
final
toggleListItems → List<Widget>
final
toggleTextStyle → TextStyle?
final
topLabel → Widget?
final
topLabelAlignment → CrossAxisAlignment?
final
vExt → VExt?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<VToggle>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited