VToggleStyle class

Inheritance

Constructors

VToggleStyle({Color? pressedSplashColor, Color? selectedBorderColor, Color? unselectedBorderColor, Color? toggleFillColor, Color? disabledBorderColor, Color? bottomBarColor, Color? bottomBarDisabledColor, Color? bottomBarUnselectedColor, double? borderRadius, double? height, double? minimumWidth})
const

Properties

borderRadius → double?
final
bottomBarColor → Color?
final
bottomBarDisabledColor → Color?
final
bottomBarUnselectedColor → Color?
final
disabledBorderColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
minimumWidth → double?
final
pressedSplashColor → Color?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedBorderColor → Color?
final
toggleFillColor → Color?
final
type → Object
The extension's type.
no setterinherited
unselectedBorderColor → Color?
final

Methods

copyWith({Color? pressedSplashColor, dynamic selectedBorderColor, dynamic unselectedBorderColor, dynamic toggleFillColor, dynamic disabledBorderColor, dynamic bottomBarDisabledColor, dynamic bottomBarUnselectedColor, dynamic bottomBarColor, double? height, dynamic borderRadius, dynamic minimumWidth}) → VToggleStyle
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<VToggleStyle>? other, double t) → VToggleStyle
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited