build method
Describes the part of the user interface represented by this widget.
The framework calls this method when this widget is inserted into the tree in a given BuildContext and when the dependencies of this widget change (e.g., an InheritedWidget referenced by this widget changes). This method can potentially be called in every frame and should not have any side effects beyond building a widget.
The framework replaces the subtree below this widget with the widget returned by this method, either by updating the existing subtree or by removing the subtree and inflating a new subtree, depending on whether the widget returned by this method can update the root of the existing subtree, as determined by calling Widget.canUpdate.
Typically implementations return a newly created constellation of widgets that are configured with information from this widget's constructor and from the given BuildContext.
The given BuildContext contains information about the location in the tree at which this widget is being built. For example, the context provides the set of inherited widgets for this location in the tree. A given widget might be built with multiple different BuildContext arguments over time if the widget is moved around the tree or if the widget is inserted into the tree in multiple places at once.
The implementation of this method must only depend on:
- the fields of the widget, which themselves must not change over time, and
- any ambient state obtained from the
contextusing BuildContext.dependOnInheritedWidgetOfExactType.
If a widget's build method is to depend on anything else, use a StatefulWidget instead.
See also:
- StatelessWidget, which contains the discussion on performance considerations.
Implementation
@override
Widget build(BuildContext context) {
final dynamic defaultStyle;
if (vExt == null || vExt is VDef) {
defaultStyle = getDefaultColorScheme()!;
} else {
defaultStyle = getAltColorScheme()!;
}
final messageStyle = getMessageColorScheme()!;
final defaultBackgroundColor =
style?.defaultBackgroundColor ?? defaultStyle.surface1;
final inProgressColor = style?.inProgressColor ?? defaultStyle.active;
final successColor = style?.successColor ?? messageStyle.positiveText;
final errorIconColor = style?.errorIconColor ?? defaultStyle.surface1;
final errorIconBgColor = style?.errorIconColor ?? messageStyle.negativeText;
final incompleteColor = style?.incompleteColor ?? defaultStyle.textSubtle;
final numberTextStyle = style?.numberTextStyle ??
defaultStyle.vWizardProperties.numberTextStyle;
final borderRadius =
style?.borderRadius ?? defaultStyle.vWizardProperties.borderRadius;
return Column(
children: [
Center(
child: Row(
mainAxisSize: MainAxisSize.min,
children: List.generate(totalSteps * 2 - 1, (index) {
if (index % 2 == 0) {
// This is a step
int stepIndex = index ~/ 2;
bool isCompleted = completedSteps[stepIndex];
bool isInProgress = stepIndex == currentStep - 1;
Color? backgroundColor = defaultBackgroundColor;
Color? borderColor = incompleteColor;
Widget? childIcon;
if (hasError && isInProgress) {
backgroundColor = errorIconBgColor;
borderColor = errorIconBgColor;
childIcon = Semantics(
label: "Error, step ${stepIndex + 1} of $totalSteps",
child: VIcon(
svgIcon: VIcons.errorAltTiny,
iconHeight: 10,
iconWidth: 10,
iconColor: errorIconColor,
),
);
} else if (isCompleted && isInProgress) {
// Current step, completed: green bg, white checkmark
backgroundColor = successColor;
borderColor = successColor;
childIcon = Semantics(
label:
"Current step, completed, step ${stepIndex + 1} of $totalSteps",
child: const VIcon(
svgIcon: VIcons.checkmarkTiny,
iconHeight: 10,
iconWidth: 10,
iconColor: Colors.white,
),
);
} else if (isCompleted) {
// Completed, not current: white bg, green checkmark
backgroundColor = Colors.white;
borderColor = successColor;
childIcon = Semantics(
label: "Completed, step ${stepIndex + 1} of $totalSteps",
child: VIcon(
svgIcon: VIcons.checkmarkTiny,
iconHeight: 10,
iconWidth: 10,
iconColor: successColor,
),
);
} else if (isInProgress) {
// In progress, not completed: green bg, white number
backgroundColor = inProgressColor;
borderColor = inProgressColor;
childIcon = Semantics(
label:
"Current step, incompleted, step ${stepIndex + 1} of $totalSteps",
child: ExcludeSemantics(
child: Text(
'${stepIndex + 1}',
style: numberTextStyle.copyWith(color: Colors.white),
),
),
);
} else {
// Not completed, not current: default bg, gray number
backgroundColor = defaultBackgroundColor;
borderColor = incompleteColor;
childIcon = Semantics(
label:
"Incomplete step, step ${stepIndex + 1} of $totalSteps",
child: ExcludeSemantics(
child: Text(
'${stepIndex + 1}',
style: defaultVTheme.textStyles.uiLabelActive.copyWith(
color: incompleteColor,
fontWeight: VFontWeight.medium,
),
),
),
);
}
return Container(
decoration: BoxDecoration(
color: backgroundColor,
shape: BoxShape.circle,
border: Border.all(
color: borderColor!,
width: 1.0,
),
),
width: borderRadius,
height: borderRadius,
child: Center(
child: childIcon,
),
);
} else {
// This is a line
int leftStep = index ~/ 2;
bool isCompleted = completedSteps[leftStep];
return Container(
width: 38.0,
height: 2.0,
color:
isCompleted ? successColor : VColors.defaultActiveSubtle,
);
}
}),
),
),
],
);
}