visa_nova_flutter library
Classes
- CheckmarkableChipAttributes
- An interface for Material Design chips that can have check marks.
- Chip
- A Material Design chip.
- ChipAttributes
- An interface defining the base attributes for a Material Design chip.
- DeletableChipAttributes
- An interface for Material Design chips that can be deleted.
- DisabledChipAttributes
- An interface for Material Design chips that can be enabled and disabled.
- NestedCheckbox
- ProgressIndicator
- SelectableChipAttributes
- An interface for Material Design chips that can be selected.
- TappableChipAttributes
- An interface for Material Design chips that can be tapped.
- VAccordion
- VAccordionProperties
- Theme extension for the Visa Nova Design System.
- VAccordionStyle
- VAlt
- VAltThemeProps
- VAppBar
- VAppBarProperties
- VAppBarStyle
- VAvatarProfile
- VAvatarProperties
- VAvatarStyle
- VAvatarVertical
- VBadge
- VBadgeLabel
- VBadgeNumber
- VBadgeStyle
- VBanner
- VBannerProperties
- VBannerStyle
- VBottomBarItems
- VButton
- VButtonProperties
- VButtonStyle
- VCheckboxStyle
- VCheckboxTile
- VCheckboxValidationTile
- VChipRemovableStyle
- VChipSelectionStyle
- VChipsRemovable
- VChipsRemovableProperties
- VChipsSelection
- VChipsSelectionProperties
- VCircularProgressIndicator
- VColors
- VComboboxProperties
- VComboboxScreen
- VComboboxStyle
- VContentCard
- VContentCardProperties
- VContentCardStyle
- VDef
- VDefaultThemeProps
- VDialogContent
- VDialogNested
- VDialogNestedContent
- VDialogNestedState
- VDialogStyle
- VDivider
- VDividerProperties
- VDividerStyle
- VDropdownIcon
- VDropdownIconProperties
- VDropdownIconStyle
- VDropdownTextButton
- VDropdownTextButtonStyle
- VDropdownTextProperties
- VExt
- VFlag
- VFlagProperties
- VFlagStyle
- VFontWeight
- Namespace for Default Visa Flutter Font Weights
- VIcon
- VIconAsset
- VIconButton
- VInput
- VInputProperties
- VInputStyle
- VLink
- VLinkProperties
- VLinkStyle
- VListItem
- VListItemProperties
- VListItemStyle
- VMatCheckbox
- A material design checkbox.
- VMatCheckboxListTile
- A ListTile with a Checkbox. In other words, a checkbox with a label.
-
VMatRadio<
T> - A material design radio button.
-
VMatRadioListTile<
T> - A ListTile with a Radio. In other words, a radio button with a label.
- VMatTab
- A material design VMatTabBar vTab.
- VMatTabBar
- A material design widget that displays a horizontal row of vTabs.
- VMatTabBarView
- A page view that displays the widget which corresponds to the currently selected vTab.
- VMatTabPageSelector
- Displays a row of small circular indicators, one per vTab.
- VMatTabPageSelectorIndicator
- Displays a single circle with the specified border and background colors.
- VMessageColorSet
- VNestedCheckboxTile
- VPanel
- VPanelProperties
- VPanelStyle
- VProgressCircular
- VProgressGaugeBig
- VProgressGaugeSmall
- VProgressLinear
- VProgressProperties
- VProgressStyle
-
VRadio<
T> - VRadioStyle
- VRawChip
- A raw Material Design chip.
- VSectionMessage
- VSectionMessageStyle
- VSelect
- VSelectProperties
- VSelectStyle
- VSnackBar
- VSwitch
- VSwitchStyle
- VTab
- VTabBar
- VTabBarProperties
- VTabBarStyle
- VTextStyle
- Visa Flutter Text Style Definitions
- VTheme
- VToggle
- VToggleProperties
- VToggleStyle
- VWizard
- VWizardProperties
- VWizardStyle
Enums
- BadgeState
- BannerState
- CheckboxType
- ChipsRemovableType
- DialogState
- FlagState
- SectionMessageState
- SnackBarState
- VDividerType
- VMatTabBarIndicatorSize
- Defines how the bounds of the selected vTab indicator are computed.
Constants
- backIcon → const String
- checkboxError → const String
- checkboxLabel → const String
- close → const String
- closeIcon → const String
- errorIcon → const String
- errorIcon18 → const String
- goalIcon → const String
- historyIcon → const String
- homeIcon → const String
- iconPath → const String
- infoIcon → const String
- messageColorScheme → const VMessageColorSet
- reportIcon → const String
- searchIcon → const String
- statsIcon → const String
- statsIcon24 → const String
- successIcon → const String
- userIcon → const String
- versionNumber → const String
- visaDialectFont → const String
- visaDialogAction → const String
- visaDialogDismiss → const String
- visaIcon → const String
- warningIcon → const String
Properties
- defaultVTheme ↔ VTheme
-
getter/setter pair
Functions
-
getAltColorScheme(
) → dynamic -
getAltColorSchemeDark(
) → dynamic -
getBannerState(
dynamic bannerState) → String -
getColorScheme(
ThemeExtension scheme) → ThemeData -
getDefaultColorScheme(
) → dynamic -
getDefaultColorSchemeDark(
) → dynamic -
getMessageColorScheme(
) → VMessageColorSet? -
getSnackBarHighlight(
dynamic snackBarState) → Color -
largeSpace(
BuildContext context) → double -
mediumSpace(
BuildContext context) → double -
smallSpace(
BuildContext context) → double -
visaButtonHeight(
BuildContext context) → double -
visaButtonWidth(
BuildContext context) → double