VFlagStyle class
Constructors
-
VFlagStyle({Color? infoIconColor, Color? warningIconColor, Color? errorIconColor, Color? successIconColor, Color? linkTextColor, Color? linkUnderlineColor, Color? closeIconColor, Color? titleTextColor, Color? descriptionTextColor, TextStyle? linkTextStyle, TextStyle? titleTextStyle, TextStyle? descriptionTextStyle, EdgeInsetsGeometry? closeIconPadding, VButtonStyle? linkStyle})
-
const
Methods
-
copyWith({Color? infoIconColor, dynamic warningIconColor, dynamic errorIconColor, dynamic successIconColor, dynamic linkTextColor, dynamic linkUnderlineColor, dynamic closeIconColor, dynamic titleTextColor, dynamic descriptionTextColor, TextStyle? linkTextStyle, TextStyle? titleTextStyle, TextStyle? descriptionTextStyle, EdgeInsetsGeometry? closeIconPadding, VButtonStyle? linkStyle})
→ VFlagStyle
-
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(covariant ThemeExtension<VFlagStyle>? other, double t)
→ VFlagStyle
-
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited