VRadioStyle class
Methods
-
copyWith({Color? fillColor, dynamic fillColorPressed, dynamic fillColorDisabled, dynamic iconColor, dynamic iconColorError, dynamic titleTextColor, dynamic titleTextColorDisabled, dynamic titleTextColorError, dynamic subtitleTextColor, dynamic subtitleTextColorDisabled, dynamic subtitleTextColorError, dynamic overlayColor})
→ VRadioStyle
-
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(covariant ThemeExtension<VRadioStyle>? other, double t)
→ VRadioStyle
-
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited