VSwitchStyle class

Inheritance

Constructors

VSwitchStyle({Color? switchColor, Color? tagColor, Color? tagBorderColor, Color? borderColor, Color? trackDisabledOff, Color? trackDisabledOn, Color? thumbDisabled, Color? borderDisabledOff, Color? borderDisabledOn, Color? thumbBorderDisabled})
const

Properties

borderColor Color?
final
borderDisabledOff Color?
final
borderDisabledOn Color?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
switchColor Color?
final
tagBorderColor Color?
final
tagColor Color?
final
thumbBorderDisabled Color?
final
thumbDisabled Color?
final
trackDisabledOff Color?
final
trackDisabledOn Color?
final
type Object
The extension's type.
no setterinherited

Methods

copyWith({Color? switchColor, dynamic tagColor, dynamic tagBorderColor, dynamic borderColor, dynamic trackDisabledOff, dynamic trackDisabledOn, dynamic thumbDisabled, dynamic borderDisabledOff, dynamic borderDisabledOn, dynamic thumbBorderDisabled}) VSwitchStyle
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<VSwitchStyle>? other, double t) VSwitchStyle
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited